@@ -1,5 +1,5 @@
 #!/usr/bin/python
-# $Id: wlink.py 1777 2017-12-03 19:33:05Z mwall $
+# $Id: wlink.py 1783 2018-01-29 11:57:57Z mwall $
 # Copyright 2014 Matthew Wall
 """weewx driver for WeatherLink web sites
    download data from a weatherlink site for use in weewx
@@ -50,7 +50,7 @@ import weewx
 import weewx.drivers
 
 DRIVER_NAME = "WeatherLink"
-DRIVER_VERSION = "0.13"
+DRIVER_VERSION = "0.14"
 
 if weewx.__version__ < "3":
     raise weewx.UnsupportedFeature("weewx 3 is required, found %s" %
@@ -75,6 +75,12 @@ def logdev(msg):
 #    print msg
     pass
 
+def try_float(x):
+    try:
+        return float(x)
+    except ValueError:
+        return None
+
 def loader(config_dict, engine):
     return WeatherLink(**config_dict['WeatherLink'])
 
@@ -425,31 +431,29 @@ class WLParserA(HTMLParser):
             self.packet['windDir'] = compass_points[data]
         elif self.last_value is not None:
             if data == self.last_value:
-                try:
-                    v = float(self.last_value)
-                    self.packet['outTemperature'] = v
-                except ValueError:
-                    pass
+                self.packet['outTemperature'] = try_float(self.last_value)
             elif data == 'km/h' or data == 'Mph':
-                self.packet['windSpeed'] = float(self.last_value)
+                self.packet['windSpeed'] = try_float(self.last_value)
             elif data == '%':
-                self.packet['outHumidity'] = float(self.last_value)
+                self.packet['outHumidity'] = try_float(self.last_value)
             self.last_value = None
         elif re.search('\d+mm', data):
             m = re.search('(\d+)mm', data)
-            self.packet['rain'] = float(m.group(1)) / 10 # weewx wants cm
+            self.packet['rain'] = try_float(m.group(1))
+            if self.packet['rain'] is not None:
+                self.packet['rain'] /= 10 # weewx wants cm
         elif re.search('[\d.]+mb', data):
             m = re.search('([\d.]+)mb', data)
-            self.packet['barometer'] = float(m.group(1))
+            self.packet['barometer'] = try_float(m.group(1))
         elif re.search('[\d.]+hPa', data):
             m = re.search('([\d.]+)hPa', data)
-            self.packet['barometer'] = float(m.group(1))
+            self.packet['barometer'] = try_float(m.group(1))
         elif re.search('[\d.]+"', data):
             m = re.search('([\d.]+)"', data)
             if self.last_key == 'Rain':
-                self.packet['rain'] = float(m.group(1))
+                self.packet['rain'] = try_float(m.group(1))
             elif self.last_key == 'Barometer':
-                self.packet['barometer'] = float(m.group(1))
+                self.packet['barometer'] = try_float(m.group(1))
             self.last_key = None
         else:
             self.last_value = data
@@ -499,43 +503,41 @@ class WLParserB(HTMLParser):
                 # do not reset last_key since we still need a wind speed
             elif re.search('[\d.]+', data):
                 m = re.search('([\d.]+)', data)
-                self.packet['windSpeed'] = float(m.group(1))
+                self.packet['windSpeed'] = try_float(m.group(1))
                 logdev('windSpeed: %s' % self.packet.get('windSpeed')) 
                 self.last_key = None
         if self.last_key == 'Temperature':
-            try:
-                v = float(data)
-                self.packet['outTemperature'] = v
-                logdev('outTemperature: %s' % self.packet['outTemperature'])
-                self.last_key = None
-            except ValueError:
-                pass
+            self.packet['outTemperature'] = try_float(data)
+            logdev('outTemperature: %s' % self.packet['outTemperature'])
+            self.last_key = None
         if self.last_key == 'Humidity':
-            self.packet['outHumidity'] = float(data)
+            self.packet['outHumidity'] = try_float(data)
             logdev('outHumidity: %s' % self.packet['outHumidity'])
             self.last_key = None
         if self.last_key == 'Rain':
             if re.search('[\d.]+mm', data):
                 m = re.search('([\d.]+)mm', data)
-                self.packet['rain'] = float(m.group(1)) / 10 # weewx wants cm
+                self.packet['rain'] = try_float(m.group(1))
+                if self.packet['rain'] is not None:
+                    self.packet['rain'] /= 10 # weewx wants cm
                 logdev('rain: %s' % self.packet['rain'])
             elif re.search('[\d.]+"', data):
                 m = re.search('([\d.]+)"', data)
-                self.packet['rain'] = float(m.group(1))
+                self.packet['rain'] = try_float(m.group(1))
                 logdev('rain: %s' % self.packet['rain'])
             self.last_key = None
         if self.last_key == 'Barometer':
             if re.search('[\d.]+mb', data):
                 m = re.search('([\d.]+)mb', data)
-                self.packet['barometer'] = float(m.group(1))
+                self.packet['barometer'] = try_float(m.group(1))
                 logdev('barometer: %s' % self.packet['barometer']) # FIXME
             elif re.search('[\d.]+hPa', data):
                 m = re.search('([\d.]+)hPa', data)
-                self.packet['barometer'] = float(m.group(1))
+                self.packet['barometer'] = try_float(m.group(1))
                 logdev('barometer: %s' % self.packet['barometer']) # FIXME
             elif re.search('[\d.]+"', data):
                 m = re.search('([\d.]+)"', data)
-                self.packet['barometer'] = float(m.group(1))
+                self.packet['barometer'] = try_float(m.group(1))
                 logdev('barometer: %s' % self.packet['barometer'])
             self.last_key = None
 
